skhubness.reduction.LocalScaling
================================

.. currentmodule:: skhubness.reduction

.. autoclass:: LocalScaling

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LocalScaling.__init__
      ~LocalScaling.fit
      ~LocalScaling.transform
   
   

   
   
   